===============
Release History
===============

.. Changelog entries should follow this format:

   version (release date)
   ======================

   **section**

   - One-line description of change (link to Github issue/PR)

.. Changes should be organized in one of several sections:

   - Added
   - Changed
   - Removed
   - Fixed

0.1.1 (January 7, 2017)
=======================

This release fixes a few bugs with command line handling.
If you run into any issues with this release, please
`file an issue <https://github.com/tbekolay/ti/issues>`_!

0.1.0 (June 27, 2016)
=====================

First release of ``ti`` on PyPI!
Thanks to all of the original authors,
particularly Shrikant Sharat,
who has turned over development of ``ti``
to me, Trevor Bekolay.
